<?php

namespace FiloBlu\Rma\Block\Adminhtml\System\Config;

use FiloBlu\Rma\Api\Model\Config\Reader;
use Magento\Backend\Block\Template\Context;
use Magento\Config\Block\System\Config\Form\Field\FieldArray\AbstractFieldArray;
use Magento\Eav\Model\Config;
use Magento\Framework\Exception\LocalizedException;
use Magento\Framework\View\Element\Html\Select;

/**
 *
 */
class ReasonToDisableEmail extends AbstractFieldArray
{

    /**
     * @var Config $eavConfig ,
     */
    protected $eavConfig;

    /**
     * @var Reader
     */
    private $reader;

    /**
     * Constructor
     *
     * @param Config $eavConfig
     * @param Context $context
     * @param Reader $reader
     * @param array $data
     */
    public function __construct(
        Config  $eavConfig,
        Context $context,
        Reader  $reader,
        array   $data = []
    )
    {
        parent::__construct($context, $data);
        $this->eavConfig = $eavConfig;
        $this->reader = $reader;
    }


    /**
     * @throws LocalizedException
     */
    protected function _prepareToRender()
    {
        $attribute = $this->eavConfig->getAttribute('rma_item', 'reason');
        $options = $attribute->getSource()->getAllOptions();

        $brandReasons = [];

        foreach ($options as $option) {
            if ($option['value']) {
                $brandReasons[] = ['value' => $option['value'], 'label' => $option['label']];
            }
        }

        array_unshift($brandReasons, ['value' => '*', 'label' => __('-- Select --')]);

        $rma_resons_block = $this->getLayout()->createBlock(Select::class)
            ->setId($this->_getCellInputElementId('<%- _id %>', 'rma_reson'))
            ->setName($this->_getCellInputElementName('rma_reson'))
            ->setClass('select')
            ->setOptions($brandReasons);

        $this->addColumn('rma_reson', [
            'label'    => __('Rma Reason'),
            'renderer' => $rma_resons_block
        ]);

        $this->_addAfter = false;
        $this->_addButtonLabel = __('Add Rma Reason');
    }
}
